.. -*- rst -*-

ZeroGroup
=========

Package Description
-------------------
ZeroGroup is a simple wrapper class for managing multiple ZeroMQ sockets and 
streams.

Installation
------------
The package may be installed as follows: ::

    pip install zerogroup

Usage Examples
--------------
See the `examples` directory for demos of how to use the class.

Development
-----------
The latest release of the package may be obtained from
`Github <https://github.com/lebedov/zerogroup>`_.

Author
------
See the included AUTHORS.rst file for more information.

License
-------
This software is licensed under the
`BSD License <http://www.opensource.org/licenses/bsd-license.php>`_.
See the included LICENSE.rst file for more information.
